Christian Costa : d3dx9_36/tests: Move surface tests into surface.c.

Alexandre Julliard julliard at winehq.org
Wed Apr 14 11:25:00 CDT 2010


Module: wine
Branch: master
Commit: 79b8de1263b02eb2a3319885b172473fa7021b37
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=79b8de1263b02eb2a3319885b172473fa7021b37

Author: Christian Costa <titan.costa at wanadoo.fr>
Date:   Mon Apr 12 21:36:26 2010 +0200

d3dx9_36/tests: Move surface tests into surface.c.

---

 dlls/d3dx9_36/tests/Makefile.in              |    2 +-
 dlls/d3dx9_36/tests/{texture.c => surface.c} |    4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/dlls/d3dx9_36/tests/Makefile.in b/dlls/d3dx9_36/tests/Makefile.in
index 59ac277..b9ad40d 100644
--- a/dlls/d3dx9_36/tests/Makefile.in
+++ b/dlls/d3dx9_36/tests/Makefile.in
@@ -13,7 +13,7 @@ C_SRCS = \
 	math.c \
 	mesh.c \
 	shader.c \
-	texture.c
+	surface.c
 
 RC_SRCS = rsrc.rc
 
diff --git a/dlls/d3dx9_36/tests/texture.c b/dlls/d3dx9_36/tests/surface.c
similarity index 99%
rename from dlls/d3dx9_36/tests/texture.c
rename to dlls/d3dx9_36/tests/surface.c
index 2d6f768..ef04afc 100644
--- a/dlls/d3dx9_36/tests/texture.c
+++ b/dlls/d3dx9_36/tests/surface.c
@@ -1,5 +1,5 @@
 /*
  * Tests for the D3DX9 texture functions
  *
  * Copyright 2009 Tony Wasserka
  *
@@ -489,7 +489,7 @@ static void test_D3DXLoadSurface(IDirect3DDevice9 *device)
     if(testbitmap_ok) DeleteFileA("testbitmap.bmp");
 }
 
-START_TEST(texture)
+START_TEST(surface)
 {
     HWND wnd;
     IDirect3D9 *d3d;
@@ -1,5 +1,5 @@
 /*
- * Tests for the D3DX9 texture functions
+ * Tests for the D3DX9 surface functions
  *
  * Copyright 2009 Tony Wasserka




More information about the wine-cvs mailing list